"use strict";
// src/id-generation.ts
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNextCutId = exports.getNextSceneId = void 0;
const vscode = require("vscode");
const yaml = require("js-yaml");
async function getNextSceneId() {
    const editor = vscode.window.activeTextEditor;
    if (!editor)
        return 1;
    try {
        const text = editor.document.getText();
        const parsed = yaml.load(text);
        const sceneIds = (parsed?.sequences || [])
            .flatMap((seq) => seq.scenes || [])
            .map((scene) => scene.id || 0);
        const maxSceneId = sceneIds.length > 0 ? Math.max(...sceneIds) : 0;
        return maxSceneId + 1;
    }
    catch (error) {
        vscode.window.showErrorMessage('シーンID取得失敗: YAML解析エラー');
        return 1;
    }
}
exports.getNextSceneId = getNextSceneId;
async function getNextCutId() {
    const editor = vscode.window.activeTextEditor;
    if (!editor)
        return 1;
    try {
        const text = editor.document.getText();
        const parsed = yaml.load(text);
        const cutIds = (parsed?.sequences || [])
            .flatMap((seq) => seq.scenes || [])
            .flatMap((scene) => scene.cuts || [])
            .map((cut) => cut.id || 0);
        const maxCutId = cutIds.length > 0 ? Math.max(...cutIds) : 0;
        return maxCutId + 1;
    }
    catch (error) {
        vscode.window.showErrorMessage('カットID取得失敗: YAML解析エラー');
        return 1;
    }
}
exports.getNextCutId = getNextCutId;
//# sourceMappingURL=id-generation.js.map