"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.countTotalDurationInRange = void 0;
const yaml = require("js-yaml");
function countTotalDurationInRange(text, sequenceRange, sceneRange) {
    let yamlData;
    try {
        yamlData = yaml.load(text);
    }
    catch (err) {
        throw new Error('YAMLのパースに失敗しました。');
    }
    if (!yamlData?.sequences) {
        throw new Error('YAML構造が不正です。sequencesが見つかりません。');
    }
    let total = 0;
    for (const seq of yamlData.sequences) {
        if (!seq?.id || seq.id < sequenceRange[0] || seq.id > sequenceRange[1])
            continue;
        for (const scene of seq.scenes ?? []) {
            if (!scene?.id || scene.id < sceneRange[0] || scene.id > sceneRange[1])
                continue;
            for (const cut of scene.cuts ?? []) {
                if (typeof cut.duration === 'number') {
                    total += cut.duration;
                }
            }
        }
    }
    return total;
}
exports.countTotalDurationInRange = countTotalDurationInRange;
//# sourceMappingURL=countTotalDurationInRange.js.map