"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractDialogueTexts = void 0;
const yaml = require("js-yaml");
function extractDialogueTexts(yamlText) {
    let yamlData;
    try {
        yamlData = yaml.load(yamlText);
    }
    catch (err) {
        throw new Error('YAMLのパースに失敗しました。');
    }
    if (!yamlData?.sequences) {
        throw new Error('YAML構造が不正です。sequencesが見つかりません。');
    }
    const texts = [];
    for (const seq of yamlData.sequences) {
        if (!seq?.scenes)
            continue;
        for (const scene of seq.scenes) {
            if (!scene?.cuts)
                continue;
            for (const cut of scene.cuts) {
                if (!cut?.dialogue)
                    continue;
                for (const line of cut.dialogue) {
                    if (line?.text) {
                        texts.push(line.text);
                    }
                }
            }
        }
    }
    return texts;
}
exports.extractDialogueTexts = extractDialogueTexts;
//# sourceMappingURL=extractDialogueTexts.js.map